@@ -7,10 +7,19 @@ use warnings;
 
 use Bit::Vector;
 use DBI;
-use Data::PowerSet;
+use List::PowerSet qw( powerset_lazy );
 use IO::File;
 
-our $VERSION = '0.04';
+use Memoize;
+memoize('_does_not_overlap');
+memoize('power');
+memoize('_reconstruct');
+memoize('_grouping');
+memoize('score_parts');
+memoize('_rle');
+memoize('_or_together');
+
+our $VERSION = '0.05';
 
 
 
@@ -143,10 +152,10 @@ sub power {
     my $self = shift;
 
     # Get a new powerset generator.
-    my $power = Data::PowerSet->new(sort keys %{ $self->{masks} });
+    my $power = powerset_lazy(sort keys %{ $self->{masks} });
 
     # Consider each member of the powerset.. to save or skip?
-    while (my $collection = $power->next) {
+    while (my $collection = $power->()) {
 #        warn "C: @$collection\n";
 
         # Save this collection if it has only one item.
@@ -372,7 +381,7 @@ Lingua::Word::Parser - Parse a word into known and unknown parts
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -396,7 +405,7 @@ version 0.04
  my $scored  = $p->score;
 
  # The best guess is the last sorted score-set:
- warn Dumper $scored->{ [ sort keys %$score ]->[-1] };
+ warn Dumper $scored->{ [ sort keys %$scored ]->[-1] };
 
 =head1 DESCRIPTION
 
@@ -471,6 +480,8 @@ L<Lingua::TokenParse> - The predecessor of this module.
 
 L<http://en.wikipedia.org/wiki/Affix> is the tip of the iceberg...
 
+L<https://github.com/ology/Word-Part> a friendly L<Dancer> user interface.
+
 =head1 AUTHOR
 
 Gene Boggs <gene@cpan.org>
